"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
// Production webpack config for client code
var MiniCssExtractPlugin = require('mini-css-extract-plugin');
var CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
var _require = require('kyt-utils/paths')(),
  clientSrcPath = _require.clientSrcPath,
  assetsBuildPath = _require.assetsBuildPath,
  publicSrcPath = _require.publicSrcPath;
var _require2 = require('kyt-runtime/webpack'),
  kytWebpackPlugins = _require2.kytWebpackPlugins;
var postcssLoader = require('../utils/getPostcssLoader');
var getPolyfill = require('./getPolyfill');
module.exports = function (options) {
  return {
    mode: 'production',
    target: 'web',
    devtool: 'source-map',
    entry: {
      main: [getPolyfill(options.type), "".concat(clientSrcPath, "/index.js")].filter(Boolean)
    },
    output: {
      path: assetsBuildPath,
      filename: '[name]-[chunkhash].js',
      chunkFilename: '[name]-[chunkhash].js',
      publicPath: options.publicPath
    },
    module: {
      rules: [{
        test: /\.module\.(sc|c)ss$/,
        use: [MiniCssExtractPlugin.loader, {
          loader: 'css-loader',
          options: {
            sourceMap: true,
            modules: {
              localIdentName: 'kyt-[hash:base64:5]'
            }
          }
        }, postcssLoader, {
          loader: 'sass-loader',
          options: {
            sourceMap: true
          }
        }],
        exclude: [publicSrcPath]
      }]
    },
    plugins: [].concat((0, _toConsumableArray2["default"])(kytWebpackPlugins(options)), [new MiniCssExtractPlugin({
      filename: '[name]-[contenthash].css',
      chunkFilename: '[name]-[contenthash].css'
    })]),
    optimization: {
      moduleIds: 'hashed',
      runtimeChunk: {
        name: function name(entrypoint) {
          return "runtime~".concat(entrypoint.name);
        }
      },
      minimizer: [new CssMinimizerPlugin()],
      splitChunks: {
        cacheGroups: {
          vendor: {
            test: /[\\/]node_modules[\\/]/,
            name: 'vendor',
            chunks: 'all',
            minChunks: 2
          },
          styles: {
            name: 'cssModulesStyles',
            test: /\.module\.s?css$/,
            chunks: 'all',
            minChunks: 1,
            reuseExistingChunk: true,
            enforce: true
          }
        }
      }
    }
  };
};