"use strict";

// Compiles the {server, client} configurations
// For use by the client and server compilers.

var merge = require('webpack-merge');
var logger = require('kyt-utils/logger');
var clone = require('lodash.clonedeep');
var findBabelConfigSync = require('find-babel-config').sync;
var _require = require('kyt-utils/paths')(),
  userRootPath = _require.userRootPath;

// base configs
var baseConfig = require('../config/webpack.base');
// dev configs
var devClientConfig = require('../config/webpack.dev.client');
var devServerConfig = require('../config/webpack.dev.server');
// prod configs
var prodClientConfig = require('../config/webpack.prod.client');
var prodServerConfig = require('../config/webpack.prod.server');
module.exports = function (config) {
  var environment = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'development';
  var clientURL = config.clientURL,
    serverURL = config.serverURL,
    externalModulesAllowlist = config.externalModulesAllowlist;
  var clientConfig = devClientConfig;
  var serverConfig = devServerConfig;
  var clientOptions = {
    type: 'client',
    serverURL: serverURL,
    clientURL: clientURL,
    environment: environment,
    publicPath: "".concat(clientURL.href),
    publicDir: 'src/public'
  };

  // These are the only differences between dev & prod
  if (environment === 'production') {
    clientConfig = prodClientConfig;
    serverConfig = prodServerConfig;
    clientOptions = merge(clientOptions, {
      publicPath: config.productionPublicPath,
      publicDir: 'build/public'
    });
  }
  var serverOptions = merge(clientOptions, {
    type: 'server',
    externalModulesAllowlist: externalModulesAllowlist
  });
  var hasBabelrc = findBabelConfigSync(userRootPath);
  if (!hasBabelrc || !hasBabelrc.config) {
    logger.info('No user Babel config found. Using kyt default babel preset...');
  }

  // Merge options with static webpack configs
  clientConfig = merge.smartStrategy({
    plugins: 'prepend'
  })(baseConfig(clientOptions), clientConfig(clientOptions));
  serverConfig = merge.smart(baseConfig(serverOptions), serverConfig(serverOptions));

  // Modify via userland config
  try {
    clientConfig = config.modifyWebpackConfig(clone(clientConfig), clientOptions);
    serverConfig = config.modifyWebpackConfig(clone(serverConfig), serverOptions);
  } catch (error) {
    logger.error('Error in your kyt.config.js modifyWebpackConfig():', error);
    process.exit(1);
  }
  if (config.debug) {
    logger.debug('Client webpack configuration:', clientConfig);
    logger.debug('\n\n');
    logger.debug('Server webpack configuration:', serverConfig);
  }

  // A "main" entry is required in the server config.
  if (!serverConfig.entry.main) {
    logger.error('A main entry is required in the server configuration. Found: ', serverConfig.entry);
    process.exit(1);
  }
  return {
    clientConfig: clientConfig,
    serverConfig: serverConfig
  };
};