"use strict";

// Merges base and user kyt config

var path = require('path');
var shell = require('shelljs');
var merge = require('lodash.merge');
var logger = require('kyt-utils/logger');
var _require = require('kyt-utils/paths')(),
  userRootPath = _require.userRootPath,
  userKytConfigPath = _require.userKytConfigPath;
var url = require('url');
module.exports = function (optionalConfig) {
  var config;

  // base config options
  var baseConfig = {
    productionPublicPath: '/',
    serverURL: 'http://localhost:3000',
    clientURL: 'http://localhost:3001',
    hasServer: true,
    hasClient: true,
    debug: false
  };
  var kytConfigPath = optionalConfig ? path.join(userRootPath, optionalConfig) : userKytConfigPath;

  // Find user config
  if (shell.test('-f', kytConfigPath)) {
    try {
      logger.log('');
      logger.info("Using kyt config at ".concat(kytConfigPath));
      // eslint-disable-next-line global-require,import/no-dynamic-require
      config = require(kytConfigPath);
    } catch (error) {
      logger.error('Error loading your kyt.config.js:', error);
      process.exit();
    }
  }
  config = merge({}, baseConfig, config);

  // Create default identity functions for modify function
  if (typeof config.modifyWebpackConfig !== 'function') {
    config.modifyWebpackConfig = function (c) {
      return c;
    };
  }
  var validateURL = function validateURL(name, userURL) {
    // Check to see if the url has the
    // required protocol, hostname and port.
    if (!userURL.protocol || !userURL.hostname || !userURL.port) {
      logger.error("\u274C  Error: ".concat(name, " is an invalid url - ").concat(userURL.href));
    }
  };

  // Convert the URL strings into objects
  // to make them easier to work with.
  config.serverURL = url.parse(config.serverURL);
  validateURL('serverURL', config.serverURL);
  config.clientURL = url.parse(config.clientURL);
  validateURL('clientURL', config.clientURL);
  return Object.freeze(config);
};