"use strict";

var webpack = require('webpack');
var logger = require('kyt-utils/logger');
module.exports = function (webpackConfig, cb) {
  var webpackCompiler;
  var type = webpackConfig.target === 'web' ? 'Client' : 'Server';

  // Compile the webpack config
  try {
    webpackCompiler = webpack(webpackConfig);
    logger.task("".concat(type, " webpack configuration compiled"));
  } catch (error) {
    logger.error("".concat(type, " webpack config is invalid\n"), error);
    process.exit();
  }
  webpackCompiler.hooks.beforeRun.tap('kyt', function () {
    // Temporarily set the build type in the process.
    // This is used by the babel-preset-kyt-core plugin.
    process.env.KYT_ENV_TYPE = type.toLowerCase();
  });

  // Handle errors in webpack build
  webpackCompiler.hooks.done.tap('kyt', function (stats) {
    if (stats.hasErrors()) {
      logger.error("".concat(type, " build failed\n"), stats.toString());
      logger.info('See webpack error above');
    } else if (stats.hasWarnings()) {
      logger.warn("".concat(type, " build warnings"), stats.toJson().warnings.join('\n'));
    } else {
      logger.task("".concat(type, " build successful"));
    }

    // Remove the build type that we set in the "before-run" hook.
    delete process.env.KYT_ENV_TYPE;

    // Call the callback on successful build
    if (cb) {
      cb(stats);
    }
  });

  // Return the compiler
  return webpackCompiler;
};